(* I/O utility routines for ocaml
   Copyright (C) 2003 Shawn Wagner <raevnos@pennmush.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

(** Some I/O utility functions *)

(** Open a file for output and auto-flush at exit *)
val open_out: string -> out_channel

(** [print_endline] on a generic channel. *)
val output_endline: out_channel -> string -> unit

(** [print_int] on a generic channel. *)
val output_int: out_channel -> int -> unit

(** Read a line from a handle where a trailing non-escaped \ on the
line means to read the next line and concatenate it to the end of the
previous line. *)
val input_continued: ?squish:bool -> in_channel -> string
(** @param squish [true] if any leading whitespace in the continuation
of the line should be removed. Defaults to [false]. *)

(** [read_file filename] returns the contents of filename. *)
val snarf_file: string -> string
